import { Observable, Subject } from 'rxjs';
import { ApplicationService } from './application.service';
import { ApplicationApiService } from './api/application-api.service';
import { SecurityApiService } from './api/security-api.service';
import { ApplicationId } from './application-id.enum';
import { AuthService } from './auth.service';
import { Logger } from './logger/logger';
import { AuthUser } from './models';
import { ThemeService } from './theme.service';
export declare class StartupService {
    private logger;
    private authService;
    private securityApi;
    private applicationApi;
    private themeService;
    private applicationService;
    private location;
    private configurationData;
    userRefresh: Subject<any>;
    CURRENT_APP_ID: ApplicationId;
    private CURRENT_TENANT_IDENTIFIER;
    constructor(logger: Logger, authService: AuthService, securityApi: SecurityApiService, applicationApi: ApplicationApiService, themeService: ThemeService, applicationService: ApplicationService, location: any);
    load(): Promise<any>;
    setTenantIdentifier(tenantIdentifier?: string): void;
    getTenantIdentifier(): string;
    /**
     * No catchError should be set here, the security api must be called and verified before anything else.
     */
    refreshUser(): Observable<AuthUser>;
    configurationLoaded(): boolean;
    printConfiguration(): void;
    getLogo(): string;
    getAppLogoURL(): string;
    getCustomerLogoURL(): string;
    getPortalUrl(): string;
    getLoginUrl(): string;
    getLogoutUrl(): string;
    getCasUrl(): string;
    getSearchUrl(): string;
    getConfigStringValue(key: string): string;
    getConfigNumberValue(key: string): number;
    /**
     * Navigate to given url or to the portal otherwise.
     * @param url URL to be redirected to.
     */
    redirect(url?: string): void;
    getPlatformName(): string;
    getCustomer(): string;
    getCustomerTechnicalReferentEmail(): string;
    getCustomerWebsiteUrl(): string;
    getDefaultPortalTitle(): string;
    getDefaultPortalMessage(): string;
}
